#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 errors
version:              2.3.0
visibility:           public
id:                   errors-2.3.0-GHK33RN7i48B6MypYLPNAr
key:                  errors-2.3.0-GHK33RN7i48B6MypYLPNAr
license:              BSD-3-Clause
copyright:            2012, 2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".

    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.

category:             Control, Error Handling
abi:                  768c148163a9d3b2a7630bc3029b9e9f
exposed:              True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR

import-dirs:          /usr/lib/ghc-9.6.6/site-local/errors-2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/errors-2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-errors
hs-libraries:         HSerrors-2.3.0-GHK33RN7i48B6MypYLPNAr
depends:
    base-4.18.2.1 exceptions-0.10.7 safe-0.3.21-FUSW86GEeen8gJ9UgiYnyw
    text-2.0.2 transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html:         /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

